@@ -3,7 +3,7 @@
 /* 
  * Copyright (C) 2001 Havoc Pennington
  * Copyright (C) 2003 Rob Adams
- * Copyright (C) 2004, 2005 Elijah Newren
+ * Copyright (C) 2004-2006 Elijah Newren
  * 
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -146,8 +146,8 @@ void          meta_screen_set_cursor          (MetaScreen                 *scree
 void          meta_screen_update_cursor       (MetaScreen                 *screen);
 
 void          meta_screen_ensure_tab_popup    (MetaScreen                 *screen,
-                                               MetaTabList                 type);
-
+                                               MetaTabList                 list_type,
+                                               MetaTabShowType             show_type);
 void          meta_screen_ensure_workspace_popup (MetaScreen *screen);
 
 MetaWindow*   meta_screen_get_mouse_window     (MetaScreen                 *screen,
